import{a as s}from"./c.04ecc0ad.js";const a="unavailable",r="unknown",e="off",n=[a,r],o=(t=n,(s,a)=>t.includes(s,a));var t;const i=4,c=a=>s(a,4)&&"number"==typeof a.in_progress,u=s=>(s=>c(s.attributes))(s)||!!s.attributes.in_progress,p=s=>c(s)||!!s.in_progress;export{e as O,a as U,r as a,p as b,i as c,n as d,o as i,u};
